# easyfuse-src

This reposirory contains the python source code for the [EasyFuse](https://github.com/TRON-Bioinformatics/EasyFuse) pipeline. 

Usage information and documentation is provided in the [EasyFuse repository](https://github.com/TRON-Bioinformatics/EasyFuse).


### Citation

If you use EasyFuse, please cite:  [Weber D, Ibn-Salem J, Sorn P, et al. Nat Biotechnol. 2022](https://doi.org/10.1038/s41587-022-01247-9)
